<?php
/*
Plugin Name: Theme Switch
Plugin URI: http://www.nkuttler.de/nkthemeswitch/
Author: Nicolas Kuttler
Author URI: http://www.nkuttler.de/
Description: Use different wordpress theme for logged in user. Nice for theme development.
Version: 0.3.0
*/

/* 
 * widget
 * */

function nkthemeswitch_init() {
	register_sidebar_widget(__('nkthemeswitch'), 'widget_nkthemeswitch');
}
add_action('plugins_loaded', 'nkthemeswitch_init');

/*
 * main function, sets the template in the frontend
 * */

function nkthemeswitch($template = '') {
	if(current_user_can(get_option('nkthemeswitch_level'))) {
		// catch widget changes
		if ( $_POST['nkthemeswitch_theme'] && $_POST['nkthemeswitch_theme'] != get_option('nkthemeswitch_theme')) {
			update_option('nkthemeswitch_theme', $_POST['nkthemeswitch_theme']);
		}
		$template = get_option('nkthemeswitch_theme');
	}
	return $template;
}
add_filter('template', 'nkthemeswitch');
add_filter('stylesheet', 'nkthemeswitch');

/*
 * the be nice to users part of this plugin
 * */

// Hook for adding admin menus
add_action('admin_menu', 'nkthemeswitch_add_pages');

function nkthemeswitch_add_pages() {
	add_options_page('Theme Switch', 'Theme Switch', 10, 'nkthemeswitch', 'nkthemeswitch_options_page');
	function nkthemeswitch_options_page() { ?>
		<div class="wrap" style="margin: 2mm;">
		<?php
			if ($_POST['nkthemeswitch_level'] || $_POST['nkthemeswitch_theme'] || $_POST['nkthemeswitch_widgetlevel']) {
				echo '<div id="message" class="updated fade">Form submitted.<br />';
				if ($_POST['nkthemeswitch_level'] != get_option('nkthemeswitch_level') ) {
					update_option('nkthemeswitch_level', $_POST['nkthemeswitch_level']);
					echo "Level changed to " . get_option('nkthemeswitch_level');
				}
				echo '<br/>';
				if ( $_POST['nkthemeswitch_theme'] != get_option('nkthemeswitch_theme')) {
					update_option('nkthemeswitch_theme', $_POST['nkthemeswitch_theme']);
					echo "Theme changed to " . get_option('nkthemeswitch_theme');
				}
				if ($_POST['nkthemeswitch_widgetlevel'] != get_option('nkthemeswitch_widgetlevel') ) {
					update_option('nkthemeswitch_widgetlevel', $_POST['nkthemeswitch_widgetlevel']);
					echo "Widget level changed to " . get_option('nkthemeswitch_widgetlevel');
				}
				echo '<br/>';
			echo '</div>';
			}
		?>
		<h2>Theme Switch</h2>
		<p><small>nkthemeswitch</small></p>
		<p>
			This plugin allows you to use a different template for logged in users.
			<tt>level_10</tt> means admin users,
			<tt>level_7</tt> editors,
			<tt>level_2</tt> authors,
			<tt>level_0</tt> subscribers.
			Please refer to <a href="http://codex.wordpress.org/Roles_and_Capabilities">Roles and Capabilities</a> if you want to know more about the level settings.
		</p>
		<p>
			There's also a widget that you can enable in the Settings section of the dashboard if your theme is widget-ready.
			Please notice that the widget will change the theme for all logged in user of the specified level, not for an individual user.
		</p>
		<p>
			Feel free to send me feedback, patches, feature requests etc. to <a href="mailto:wp@nicolaskuttler.de">my mail address</a> or to blog about this plugin. 
			Visit my blog at <a href="http://www.nkuttler.de/">nkuttler.de</a>
			or this plugin's page at <a href="http://www.nkuttler.de/nkthemeswitch/">nkthemeswitch</a>.
			If this plugin helps you to make money, visit my <a href="http://www.amazon.de/gp/registry/24F64AHKD51LY">Amazon wishlist</a> and send me a gift.
		</p>
		<form action="" method="post">
			Show alternate template for levels &gt;=
			<select name="nkthemeswitch_level" >
			<?php
				$select = get_option('nkthemeswitch_level'); 
				echo $select;
				for ($i = 10 ; $i >= 0; $i--) {
					if ( 'level_' . $i == $select ) {
						echo "<option selected>level_$i</option>\n";
					}
					else {
						echo "<option>level_$i</option>\n";
					}
				}
			?>
			</select>
			<br />
			Which template should those users see instead?
			<select name="nkthemeswitch_theme" >
			<?php
				$select = get_option('nkthemeswitch_theme');
				$dir = get_theme_root();
				$handle = opendir($dir);
				if ($handle) {
					while (false !== ($file = readdir($handle))) {
						if ($file != '.' && $file != '..') {
							if ( $file == $select ) {
								echo "<option selected>$file</option>\n";
							}
							else {
								echo "<option>$file</option>\n";
							}
						}
					}
				}
				closedir($handle);
			?>
			</select>
			<br />
			Who should see the theme switch widget (if you enable it)?
			<select name="nkthemeswitch_widgetlevel" >
			<?php
				$select = get_option('nkthemeswitch_widgetlevel'); 
				echo $select;
				for ($i = 10 ; $i >= 0; $i--) {
					if ( 'level_' . $i == $select ) {
						echo "<option selected>level_$i</option>\n";
					}
					else {
						echo "<option>level_$i</option>\n";
					}
				}
			?>
			</select>
			<br />
			<input type="submit" value="Update settings">
		</form>
		</div>
		<?php
	}
}

function widget_nkthemeswitch($args) {
	// only show in the frontend if user has a certain level
	if(current_user_can(get_option('nkthemeswitch_widgetlevel'))) {
		extract($args);
		echo $before_widget;
		echo $before_title;
		echo 'Theme';
		echo $after_title;
		?>
		<ul>
			<li>
				<form action="" method="post" style="display: inline";>
					<select name="nkthemeswitch_theme" >
					<?php
						$select = get_option('nkthemeswitch_theme');
						$dir = get_theme_root();
						$handle = opendir($dir);
						if ($handle) {
							while (false !== ($file = readdir($handle))) {
								if ($file != '.' && $file != '..') {
									if ( $file == $select ) {
										echo "<option selected>$file</option>\n";
									}
									else {
										echo "<option>$file</option>\n";
									}
								}
							}
						}
						closedir($handle);
					?>
					</select>
					<br />
					<input type="submit" value="Switch">
				</form>
			</li>
		</ul>
		<?php
		echo $after_widget;
	}
}
?>
